/** InOut Version 2.0 -- Lastchange: 01/07/2003
 * --------------------------------------------------------------------------
 * Class for simple input and output to and from the console.
 * Uses the static methods read<Type> for input and print(<type>) for output.
 */

import java.io.*;

public class InOut
{
    /**
     * Read a single String by using the dialog form.
     * @param headline  The Headline of the form. 
     * @return          The String which was entered.
     */
    public static String readString(String headline)
    {
        System.out.print(headline + ": ");
        String answer = "";
        
        BufferedReader br = new BufferedReader (new InputStreamReader(System.in));

        try
        {
            answer = br.readLine();
        }
        catch (Exception e)
        {
            System.out.println("Fehler beim einlesen!");
        }
         
        return answer; 
    }

    /**
     * Read a single String by using the dialog form.
     * @return The String of the form.
     * @see #readString(String)
     */
    public static String readString()
    {
        return InOut.readString("");
    }

    /**
     * Read a single int-value by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The int-value.
     */
    public static int readInt(String headline)
    {
        int answer = 0;
        boolean success = false;

        while (success == false)
        {
            String s = InOut.readString(headline);          
            try
            {
                answer = Integer.parseInt(s);
                success = true;
            }
            catch (Exception e)
            {
                System.out.println("Konnte die Daten nicht in einen int-Wert umwandeln! Bitte neu eingeben!");
            }
        }

        return answer;
    }

    /**
     * Read a single int-value by using the dialog form.
     * @return          The int-value.
     * @see #readInt(String)
     */
    public static int readInt()
    {
        return InOut.readInt("");
    }

    /**
     * Read a single char by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The char.
     */
    public static char readChar(String headline)
    {
        char answer = ' ';
        boolean success = false;

        while (success == false)
        {
            String s = InOut.readString(headline);          
            if (s.length() == 1)
            {
                answer = s.charAt(0);
                success = true;
            }
            else
            {
                System.out.println("Bitte geben Sie nur ein einzelnes Zeichen ein!");
            }
        }

        return answer;
    }

    /**
     * Read a single char by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The char.
     * @see #readChar(String)
     */
    public static char readChar()
    {
        return InOut.readChar("");
    }

    /**
     * Read a single double-value by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The double-value.
     */
    public static double readDouble(String headline)
    {
        double answer = 0;
        boolean success = false;

        while (success == false)
        {
            String s = InOut.readString(headline);          
            try
            {
                answer = Double.parseDouble(s);
                success = true;
            }
            catch (Exception e)
            {
                System.out.println("Konnte die Daten nicht in einen double-Wert umwandeln! Bitte neu eingeben!");
            }
        }

        return answer;
    }

    /**
     * Read a single double-value by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The double-value.
     * @see #readDouble(String)
     */
    public static double readDouble()
    {
        return InOut.readDouble("");
    }

    /**
     * Read a single float-value by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The float-value.
     */
    public static float readFloat(String headline)
    {
        float answer = 0;
        boolean success = false;

        while (success == false)
        {
            String s = InOut.readString(headline);          
            try
            {
                answer = Float.parseFloat(s);
                success = true;
            }
            catch (Exception e)
            {
                System.out.println("Konnte die Daten nicht in einen float-Wert umwandeln! Bitte neu eingeben!");
            }
        }

        return answer;
    }

    /**
     * Read a single float-value by using the dialog form.
     * @param headline  The headline of the form.
     * @return          The float-value.
     * @see #readFloat(String)
     */
    public static double readFloat()
    {
        return InOut.readDouble("");
    }

    /**
     * Prints a single String to the dialog form.
     * @param headline  The headline of the form.
     * @param out       The String to print out.
     * @see #readString()
     */
    public static void print(String headline, String out)
    {
        System.out.println(headline + ": " + out);
    }

    /**
     * Prints a single String to the dialog form.
     * @param out       The String to print out.
     * @see #readString()
     */
    public static void print(String out)
    {
        InOut.print("", out);
    }

    /**
     * Prints a single int to the dialog form.
     * @param headline  The headline of the form.
     * @param out       The int to print out.
     * @see #readInt()
     */
    public static void print(String headline, int out)
    {
        InOut.print(headline, new Integer(out).toString());
    }

    /**
     * Prints a single String to the dialog form.
     * @param out       The int to print out.
     * @see #readInt()
     */
    public static void print(int out)
    {
        InOut.print("", out);
    }

    /**
     * Prints a single char to the dialog form.
     * @param headline  The headline of the form.
     * @param out       The char to print out.
     * @see #readChar()
     */
    public static void print(String headline, char out)
    {
        String s = new String();
        s += out;
        InOut.print(headline, s);
    }

    /**
     * Prints a single String to the dialog form.
     * @param out       The char to print out.
     * @see #readChar()
     */
    public static void print(char out)
    {
        InOut.print("", out);
    }

    /**
     * Prints a single double to the dialog form.
     * @param headline  The headline of the form.
     * @param out       The double to print out.
     * @see #readDouble()
     */
    public static void print(String headline, double out)
    {
        InOut.print(headline, new Double(out).toString());
    }

    /**
     * Prints a single double to the dialog form.
     * @param out       The double to print out.
     * @see #readDouble()
     */
    public static void print(double out)
    {
        InOut.print("", out);
    }

    /**
     * Prints a single float to the dialog form.
     * @param headline  The headline of the form.
     * @param out       The float to print out.
     * @see #readFloat()
     */
    public static void print(String headline, float out)
    {
        InOut.print(headline, new Float(out).toString());
    }

    /**
     * Prints a single float to the dialog form.
     * @param out       The float to print out.
     * @see #readFloat()
     */
    public static void print(float out)
    {
        InOut.print("", out);
    }
}